djcharme
========

CHARMe project node


See the 
`docs directory <https://github.com/CHARMe-Project/djcharme/tree/develop/djcharme/docs>`_
for information on 
`installation <https://github.com/CHARMe-Project/djcharme/blob/develop/djcharme/docs/CHARMeNodeInstallation.pdf>`_,
the 
`interface <https://github.com/CHARMe-Project/djcharme/blob/develop/djcharme/docs/CHARMeNodeICD.pdf>`_
and examples.
